@@ -1,34 +1,40 @@
-import json
 import sys
+import json
 
 import pytest
 
-from spotdl.__main__ import console_entry_point, help_notice
-from spotdl.download.downloader import DownloadManager
-from spotdl.search import spotifyClient
-
 from tests.utils import tracking_files
 
-ORIGINAL_INITIALIZE = spotifyClient.initialize
+from spotdl.download import ffmpeg
+from spotdl.search import SpotifyClient
+from spotdl.__main__ import console_entry_point
+from spotdl.parsers.argument_parser import help_notice
+from spotdl.download.downloader import DownloadManager
 
 
-def new_initialize(clientId, clientSecret):
+ORIGINAL_INITIALIZE = SpotifyClient.init
+
+
+def new_initialize(client_id, client_secret, user_auth):
     """This function allows calling `initialize()` multiple times"""
     try:
-        return spotifyClient.get_spotify_client()
+        return SpotifyClient()
     except:
-        return ORIGINAL_INITIALIZE(clientId, clientSecret)
+        return ORIGINAL_INITIALIZE(client_id, client_secret, user_auth)
 
 
 @pytest.fixture()
 def patch_dependencies(mocker, monkeypatch):
     """This is a helper fixture to patch out everything that shouldn't be called here"""
-    monkeypatch.setattr(spotifyClient, "initialize", new_initialize)
-    monkeypatch.setattr(DownloadManager, "__init__", lambda _: None)
+    monkeypatch.setattr(SpotifyClient, "init", new_initialize)
+    monkeypatch.setattr(DownloadManager, "__init__", lambda *_: None)
+    monkeypatch.setattr(ffmpeg, "has_correct_version", lambda *_: True)
     mocker.patch.object(DownloadManager, "download_single_song", autospec=True)
     mocker.patch.object(DownloadManager, "download_multiple_songs", autospec=True)
-    mocker.patch.object(DownloadManager, "resume_download_from_tracking_file", autospec=True)
-    mocker.patch.object(DownloadManager, "close", autospec=True)
+    mocker.patch.object(
+        DownloadManager, "resume_download_from_tracking_file", autospec=True
+    )
+    mocker.patch.object(DownloadManager, "__exit__", autospec=True)
 
 
 @pytest.mark.parametrize("argument", ["-h", "--help"])
@@ -66,8 +72,8 @@ def test_download_a_single_song(capsys, patch_dependencies, monkeypatch):
     out, err = capsys.readouterr()
     assert "Fetching Song...\n" in out
 
-    assert DownloadManager.download_single_song.call_count == 1
-    assert DownloadManager.download_multiple_songs.call_count == 0
+    assert DownloadManager.download_single_song.call_count == 0
+    assert DownloadManager.download_multiple_songs.call_count == 1
 
 
 @pytest.mark.vcr()
@@ -79,6 +85,7 @@ def test_download_an_album(capsys, patch_dependencies, monkeypatch):
         [
             "dummy",
             "https://open.spotify.com/album/2YMWspDGtbDgYULXvVQFM6?si=gF5dOQm8QUSo-NdZVsFjAQ",
+            "--search-threads=1",
         ],
     )
 
@@ -102,7 +109,8 @@ def test_download_a_playlist(capsys, patch_dependencies, monkeypatch):
         "argv",
         [
             "dummy",
-            "https://open.spotify.com/playlist/6ahTRKeqBqzQhZIhtIIE57",
+            "https://open.spotify.com/playlist/0slbokxiWCo9egF9UhVmmI",
+            "--search-threads=1",
         ],
     )
 
@@ -127,12 +135,13 @@ def test_search_and_download(capsys, patch_dependencies, monkeypatch):
         ],
     )
 
+    # with pytest.raises(Exception, match="No song matches found on Spotify"):
     console_entry_point()
 
     out, err = capsys.readouterr()
-    assert (
-        out == 'Searching for song "The HU - Sugaan Essenna"...\n'
-        'No song named "The HU - Sugaan Essenna" could be found on spotify\n'
+    assert out == (
+        'Searching Spotify for song named "The HU - Sugaan Essenna"...\n'
+        "No song matches found on Spotify\n\n"
     )
 
     assert DownloadManager.download_multiple_songs.call_count == 0
@@ -142,7 +151,10 @@ def test_search_and_download(capsys, patch_dependencies, monkeypatch):
 @pytest.mark.vcr()
 def test_use_tracking_file(capsys, patch_dependencies, monkeypatch, fs):
     """Fifth example - use a spotdlTrackingFile."""
-    fs.create_file("Back In Black.spotdlTrackingFile", contents=json.dumps(tracking_files.back_in_black))
+    fs.create_file(
+        "Back In Black.spotdlTrackingFile",
+        contents=json.dumps(tracking_files.back_in_black),
+    )
     monkeypatch.setattr(
         sys,
         "argv",
@@ -155,34 +167,13 @@ def test_use_tracking_file(capsys, patch_dependencies, monkeypatch, fs):
     console_entry_point()
 
     out, err = capsys.readouterr()
-    assert out == 'Preparing to resume download...\n'
+    assert out == "Preparing to resume download...\n"
 
     assert DownloadManager.resume_download_from_tracking_file.call_count == 1
     assert DownloadManager.download_multiple_songs.call_count == 0
     assert DownloadManager.download_single_song.call_count == 0
 
 
-@pytest.mark.vcr()
-def test_download_all_artist_tracks(capsys, patch_dependencies, monkeypatch):
-    """Sixth example - download all artist tracks"""
-    monkeypatch.setattr(
-        sys,
-        "argv",
-        [
-            "dummy",
-            "https://open.spotify.com/artist/6VTvaLJ9arNmKi8e1ekOwW",
-        ],
-    )
-
-    console_entry_point()
-
-    out, err = capsys.readouterr()
-    assert "Fetching artist...\n" in out
-
-    assert DownloadManager.download_multiple_songs.call_count == 1
-    assert DownloadManager.download_single_song.call_count == 0
-
-
 @pytest.mark.vcr()
 def test_multiple_elements(capsys, patch_dependencies, monkeypatch):
     """Last example - chaining tasks. Download two songs and search for one."""
@@ -191,7 +182,7 @@ def test_multiple_elements(capsys, patch_dependencies, monkeypatch):
         "argv",
         [
             "dummy",
-            "https://open.spotify.com/track/08mG3Y1vljYA6bvDt4Wqkj?si=SxezdxmlTx-CaVoucHmrUA",
+            "https://open.spotify.com/track/4EWCNWgDS8707fNSZ1oaA5",
             "https://open.spotify.com/track/2SiXAy7TuUkycRVbbWDEpo",
             "The HU - Sugaan Essenna",
         ],
@@ -200,10 +191,20 @@ def test_multiple_elements(capsys, patch_dependencies, monkeypatch):
     console_entry_point()
 
     out, err = capsys.readouterr()
+    assert "Fetching Song...\n" in out
+    assert (
+        'Found YouTube URL for "Kanye West - Heartless" : https://www.youtube.com/watch?v=s40BTpfAELs\n'
+        in out
+    )
 
-    assert 'Fetching Song...\n' in out
-    assert 'Searching for song "The HU - Sugaan Essenna"...\n' in out
-    assert 'No song named "The HU - Sugaan Essenna" could be found on spotify\n' in out
+    assert "Fetching Song...\n" in out
+    assert (
+        'Found YouTube URL for "AC/DC - You Shook Me All Night Long" : https://www.youtube.com/watch?v=SP9t2Iq_zQ8\n'
+        in out
+    )
 
-    assert DownloadManager.download_single_song.call_count == 2
-    assert DownloadManager.download_multiple_songs.call_count == 0
+    assert 'Searching Spotify for song named "The HU - Sugaan Essenna"...\n' in out
+    assert "No song matches found on Spotify\n" in out
+
+    assert DownloadManager.download_single_song.call_count == 0
+    assert DownloadManager.download_multiple_songs.call_count == 1
